# rm(list = ls())
# Sys.setenv("R_TESTS" = "")
library(testthat)
# library(collapse)

test_check("collapse")

